 title:      Markdown
 desc:       Docnado Markdown Quick Reference
 date:       2018/10/12
 version:    1.0.0
 template:   document
 nav:        Document>Markdown
 percent:    100
 authors:    enq@heinventions.com

When creating documentation it's important to use a markup language that semantically structures your text that's both easy for less technically inclined users to create and modify, but fully featured enough to deliver your documentation the way you need.

To achieve this docnado uses [`markdown`](https://en.wikipedia.org/wiki/Markdown), with it's own added features to style your documentation and present images, videos, and other multimedia the way you want.

# Markdown
Markdown on it's own is a powerful tool for presenting text information, with it you can create:

* Headings
* Tables
* Emphasis
* Lists
* Hyperlinks
* Code blocks and syntax highlighting
* Blockquotes
* Horizontal Rules
* Embedded HTML

This page starts with a quick introduction to markdown and it's features and how you can use them in a docnado document. For more information please see [The Original Specification](https://daringfireball.net/projects/markdown/).
